Module: Thoran
- Defined in:
- lib/Thoran/Array/FirstX/firstX.rb,
lib/Thoran/String/ToConst/to_const.rb,
lib/Thoran/Array/AllButFirst/all_but_first.rb
Overview
Changes since 0.2:
- Added the original version 0.1.0 of the implementation to the later 0.1.0! 0/1
- Switched the tests to spec-style. 1/2
- Added a test for the state of the array afterward, since this is meant to be an in place change. 2/3
- Added tests for the extended functionality introduced in the first version 0.1.0.